@@ -6,7 +6,7 @@ import unittest
 
 from flask import Flask
 from flask.ext.script._compat import StringIO, text_type
-from flask.ext.script import Command, Manager, Option, prompt, prompt_bool
+from flask.ext.script import Command, Manager, Option, prompt, prompt_bool, prompt_choices
 
 from pytest import raises
 
@@ -164,7 +164,7 @@ class EmptyContext(object):
     def __exit__(self, a,b,c):
         pass
 
-class TestApp(object):
+class AppForTesting(object):
     def __init__(self, verbose=False):
         self.verbose = verbose
     def test_request_context(self):
@@ -179,7 +179,7 @@ class TestManager:
 
     def setup(self):
 
-        self.app = TestApp()
+        self.app = AppForTesting()
 
     def test_with_default_commands(self):
 
@@ -566,8 +566,9 @@ class TestManager:
 
         code = run('manage.py catch pos1 --foo pos2 --bar', manager.run)
         out, err = capsys.readouterr()
+        out_list = [o.strip('u\'') for o in out.strip('[]\n').split(', ')]
         assert code == 0
-        assert "['pos1', 'pos2', '--bar']" in out
+        assert ['pos1', 'pos2', '--bar'] == out_list
 
     def test_run_bad_options(self, capsys):
         manager = Manager(self.app)
@@ -690,12 +691,57 @@ class TestManager:
             out, err = capsys.readouterr()
             assert 'correct [y]: no' in out
 
+    def test_command_with_prompt_choices(self, capsys):
+
+        manager = Manager(self.app)
+
+        @manager.command
+        def hello():
+            print(prompt_choices(name='hello', choices=['peter', 'john', 'sam']))
+
+        @Catcher
+        def hello_john(msg):
+            if re.search("hello", msg):
+                return 'john'
+
+        with hello_john:
+            code = run('manage.py hello', manager.run)
+            out, err = capsys.readouterr()
+            assert 'hello - (peter, john, sam): john' in out
+
+    def test_command_with_default_prompt_choices(self, capsys):
+
+        manager = Manager(self.app)
+
+        @manager.command
+        def hello():
+            print(prompt_choices(name='hello', choices=['peter', 'charlie', 'sam'], default="john"))
+
+        @Catcher
+        def hello_john(msg):
+            if re.search("hello", msg):
+                return '\n'
+
+        with hello_john:
+            code = run('manage.py hello', manager.run)
+            out, err = capsys.readouterr()
+            assert 'hello - (peter, charlie, sam) [john]: john' in out
+
+        @Catcher
+        def hello_charlie(msg):
+            if re.search("hello", msg):
+                return 'charlie'
+
+        with hello_charlie:
+            code = run('manage.py hello', manager.run)
+            out, err = capsys.readouterr()
+            assert 'hello - (peter, charlie, sam) [john]: charlie' in out
 
 class TestSubManager:
 
     def setup(self):
 
-        self.app = TestApp()
+        self.app = AppForTesting()
 
     def test_add_submanager(self):
 
@@ -743,11 +789,11 @@ class TestSubManager:
 
     def test_submanager_separate_options(self, capsys):
 
-        sub_manager = Manager(TestApp(verbose=True), with_default_commands=False)
+        sub_manager = Manager(AppForTesting(verbose=True), with_default_commands=False)
         sub_manager.add_command('opt', CommandWithOptionalArg())
         sub_manager.add_option('-n', '--name', dest='name_sub', required=False)
 
-        manager = Manager(TestApp(verbose=True), with_default_commands=False)
+        manager = Manager(AppForTesting(verbose=True), with_default_commands=False)
         manager.add_command('sub_manager', sub_manager)
         manager.add_option('-n', '--name', dest='name_main', required=False)
 
